**************************************
Welcome to the RIOS.CORE Documentation
**************************************

RIOS.CORE is a `Python`_ package that provides basic validation and
formatting functionality for data structures that adhere to the `RIOS`_
specifications.

.. _`Python`: https://www.python.org
.. _`RIOS`: https://rios.readthedocs.org


Overview
========

.. toctree::

   overview


API Reference
=============

.. toctree::

   api


Change History
==============

.. toctree::

   changes


License
=======

.. toctree::
   :maxdepth: 1

   license


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

